import type { EnumOption, Option } from "./index";
/**
 * Primary options show up in the web UI in the "Language" settings tab,
 * Secondary options in "Other".
 * CLI is only for cli
 */
export type OptionKind = "primary" | "secondary" | "cli";
export interface OptionDefinition<Name extends string = string, T = unknown> {
    alias?: string;
    defaultOption?: boolean;
    defaultValue?: T;
    description: string;
    kind?: OptionKind;
    multiple?: boolean;
    name: Name;
    type: StringConstructor | BooleanConstructor;
    typeLabel?: string;
}
export type OptionName<O> = O extends Option<infer Name, unknown> ? Name : never;
export type OptionValue<O> = O extends EnumOption<string, infer EnumMap, infer EnumKey> ? EnumMap[EnumKey] : O extends Option<string, infer Value> ? Value : never;
export type OptionKey<O> = O extends EnumOption<string, Record<string, unknown>, infer EnumKey> ? EnumKey : O;
export type OptionMap<T> = {
    [K in keyof T as OptionName<T[K]>]: OptionKey<T[K]>;
};
export type OptionValues<T> = {
    [K in keyof T]: OptionValue<T[K]>;
};
