import { type RenderContext } from "../../Renderer";
import { BooleanOption, EnumOption } from "../../RendererOptions";
import { TargetLanguage } from "../../TargetLanguage";
import { type Type } from "../../Type";
import { type StringTypeMapping } from "../../TypeBuilder";
import { type FixMeOptionsType } from "../../types";
import { PythonRenderer } from "./PythonRenderer";
export interface PythonFeatures {
    dataClasses: boolean;
    typeHints: boolean;
}
export declare const pythonOptions: {
    features: EnumOption<"python-version", {
        "3.5": {
            typeHints: boolean;
            dataClasses: boolean;
        };
        "3.6": {
            typeHints: boolean;
            dataClasses: boolean;
        };
        "3.7": {
            typeHints: boolean;
            dataClasses: boolean;
        };
    }, "3.5" | "3.6" | "3.7">;
    justTypes: BooleanOption<"just-types">;
    nicePropertyNames: BooleanOption<"nice-property-names">;
    pydanticBaseModel: BooleanOption<"pydantic-base-model">;
};
export declare const pythonLanguageConfig: {
    readonly displayName: "Python";
    readonly names: readonly ["python", "py"];
    readonly extension: "py";
};
export declare class PythonTargetLanguage extends TargetLanguage<typeof pythonLanguageConfig> {
    constructor();
    getOptions(): typeof pythonOptions;
    get stringTypeMapping(): StringTypeMapping;
    get supportsUnionsWithBothNumberTypes(): boolean;
    get supportsOptionalClassProperties(): boolean;
    needsTransformerForType(t: Type): boolean;
    protected makeRenderer(renderContext: RenderContext, untypedOptionValues: FixMeOptionsType): PythonRenderer;
}
